==> haskell-microlens-mtl-0.1.10.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-mtl
version: 0.1.10.0
id: microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
key: microlens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.Mtl Lens.Micro.Mtl.Internal
abi: 3879b36f096457c28f186a72e3cb1340
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-mtl-0.1.10.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/microlens-mtl-0.1.10.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/microlens-mtl-0.1.10.0
hs-libraries: HSmicrolens-mtl-0.1.10.0-Ft6UWhmjzht21aufTB77pg
depends:
    base-4.9.0.0 microlens-0.4.8.0-9sB7IE1nvPRFUzu1zwDBDS
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock
haddock-html: /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-mtl-0.1.11.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-mtl
version: 0.1.11.0
id: microlens-mtl-0.1.11.0-JZGlAY1k7Eo2CcDKB6BH2V
key: microlens-mtl-0.1.11.0-JZGlAY1k7Eo2CcDKB6BH2V
license: BSD3
maintainer: Artyom <yom@artyom.me>
homepage: http://github.com/aelve/microlens
synopsis: microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/aelve/microlens#readme on Github>.
category: Data, Lenses
author: Edward Kmett, Artyom
exposed: True
exposed-modules:
    Lens.Micro.Mtl Lens.Micro.Mtl.Internal
abi: 57a3cdd30e4b992b26ae7cdde5fea385
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-mtl-0.1.11.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/microlens-mtl-0.1.11.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/microlens-mtl-0.1.11.0
hs-libraries: HSmicrolens-mtl-0.1.11.0-JZGlAY1k7Eo2CcDKB6BH2V
depends:
    base-4.9.1.0 microlens-0.4.8.0-5PXN9DedWooJg6UJ24ter0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock
haddock-html: /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
